==> ng2-select2-bootstrap-0.1.0.tgz: package/src/component/select.component.ts <==
import {
    Component, OnInit, Input, AfterViewInit, ElementRef, OnDestroy, forwardRef, NgZone, Output, EventEmitter,
    TemplateRef, ViewContainerRef, HostListener, ViewChild
} from '@angular/core';
import {NG_VALUE_ACCESSOR, ControlValueAccessor} from "@angular/forms";
import {Select} from './../common/select';

@Component({
    selector: 'select2-select',
    templateUrl :'./../view/select.component.html',
    providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => SelectComponent),
            multi: true
        }
    ],
    host: {
        '(document:click)': 'clickForaComponent($event)',
        '(focus)': 'setFocus(true)',
        '(blur)': 'setFocus(false)',
    },
})
export class SelectComponent extends Select implements ControlValueAccessor{


    @Input() name                     : any;
    @Input() classe                   : any;
    @Input() placeholder              : string = 'Selecione';
    @Input() templateResultado        : TemplateRef<any>;
    @Input() templateSelecionado      : TemplateRef<any>;
    @Input() templateSemResultado     : TemplateRef<any>;
    @Input() resultadoCompleto        : boolean = false;
    @Input() indiceId                 : string = 'id';
    @Input() indiceNome               : string = 'nome';
    @Input() set valores(valor : any){
        this._valores = valor;
        this.valoresExibir = valor;
    }
    @Output() change = new EventEmitter<any>();
    @ViewChild('campoBusca') campoBusca : ElementRef;
    

    constructor(
        public elementRef   : ElementRef,
        public zone         : NgZone
    ){
        super(elementRef, zone);
    }

    
    abrir(){
        this.aberto = !this.aberto;
        if(this.aberto){
            this.campoBusca.nativeElement.focus();
            this.setFocus(true);
            this.buscar('');
        }
    }

    selecionar(item){
        this.data = item;

        this.updateValue(this.data);
        this.fechar();

        //apaga campo de busca
        this.campoBusca.nativeElement.value = '';
    }
    limpar(){
        this.data = null;
        this.updateValue(null);
        this.aberto = true;
    }
    remove(item){
        this.removePorResultadoCompleto(item)
    }

    buscar(valor){
        this.valorPesquisado = valor;

        this.valoresExibir = this._valores.filter(item => item[this.indiceNome].indexOf(this.valorPesquisado) !== -1);
    }



    get value(): any { return this._value; };
    @Input() set value(v) {
        if (v !== this._value) {
            this._value = v;
            this._onChangeCallback(v);
        }
    }

    

    
    
    
    writeValue(value: any): void {
        this.data = value;
        this._value = value;
    }
    updateValue (value: any) {
        this.zone.run(() => {
            this._value = value;

            this.onChange(value);
            this._onTouchedCallback();
            this.change.emit(value);


        });
    }
    
    onChange (_: any) {}
    onTouched () {}
    registerOnChange (fn: any) { this.onChange = fn; }
    registerOnTouched (fn: any) { this.onTouched = fn; }
    _onChangeCallback (_: any) {}
    _onTouchedCallback () {}

}

==> ng2-select2-bootstrap-0.1.1.tgz: package/src/component/select.component.ts <==
import {
    Component, OnInit, Input, AfterViewInit, ElementRef, OnDestroy, forwardRef, NgZone, Output, EventEmitter,
    TemplateRef, ViewContainerRef, HostListener, ViewChild
} from '@angular/core';
import {NG_VALUE_ACCESSOR, ControlValueAccessor} from "@angular/forms";
import {Select} from './../common/select';

@Component({
    selector: 'select2-select',
    templateUrl :'./select.component.html',
    providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => SelectComponent),
            multi: true
        }
    ],
    host: {
        '(document:click)': 'clickForaComponent($event)',
        '(focus)': 'setFocus(true)',
        '(blur)': 'setFocus(false)',
    },
})
export class SelectComponent extends Select implements ControlValueAccessor{


    @Input() name                     : any;
    @Input() classe                   : any;
    @Input() placeholder              : string = 'Selecione';
    @Input() templateResultado        : TemplateRef<any>;
    @Input() templateSelecionado      : TemplateRef<any>;
    @Input() templateSemResultado     : TemplateRef<any>;
    @Input() resultadoCompleto        : boolean = false;
    @Input() indiceId                 : string = 'id';
    @Input() indiceNome               : string = 'nome';
    @Input() set valores(valor : any){
        this._valores = valor;
        this.valoresExibir = valor;
    }
    @Output() change = new EventEmitter<any>();
    @ViewChild('campoBusca') campoBusca : ElementRef;
    

    constructor(
        public elementRef   : ElementRef,
        public zone         : NgZone
    ){
        super(elementRef, zone);
    }

    
    abrir(){
        this.aberto = !this.aberto;
        if(this.aberto){
            this.campoBusca.nativeElement.focus();
            this.setFocus(true);
            this.buscar('');
        }
    }

    selecionar(item){
        this.data = item;

        this.updateValue(this.data);
        this.fechar();

        //apaga campo de busca
        this.campoBusca.nativeElement.value = '';
    }
    limpar(){
        this.data = null;
        this.updateValue(null);
        this.aberto = true;
    }
    remove(item){
        this.removePorResultadoCompleto(item)
    }

    buscar(valor){
        this.valorPesquisado = valor;

        this.valoresExibir = this._valores.filter(item => item[this.indiceNome].indexOf(this.valorPesquisado) !== -1);
    }



    get value(): any { return this._value; };
    @Input() set value(v) {
        if (v !== this._value) {
            this._value = v;
            this._onChangeCallback(v);
        }
    }

    

    
    
    
    writeValue(value: any): void {
        this.data = value;
        this._value = value;
    }
    updateValue (value: any) {
        this.zone.run(() => {
            this._value = value;

            this.onChange(value);
            this._onTouchedCallback();
            this.change.emit(value);


        });
    }
    
    onChange (_: any) {}
    onTouched () {}
    registerOnChange (fn: any) { this.onChange = fn; }
    registerOnTouched (fn: any) { this.onTouched = fn; }
    _onChangeCallback (_: any) {}
    _onTouchedCallback () {}

}
